# CTAO Science Analysis Tools

[![CI](https://gitlab.cta-observatory.org/cta-computing/suss/science-analysis-tools/science-analysis-tools/badges/main/pipeline.svg?key_text=CI&key_width=25)](https://gitlab.cta-observatory.org/cta-computing/suss/science-analysis-tools/science-analysis-tools/-/pipelines/main/latest)
[![Test Report](https://gitlab.cta-observatory.org/cta-computing/suss/science-analysis-tools/science-analysis-tools/badges/main/pipeline.svg?key_text=Test%20Report)](https://gitlab.cta-observatory.org/cta-computing/suss/science-analysis-tools/science-analysis-tools/-/jobs/artifacts/main/file/test_report.pdf?job=build-test-report)
[![Docs](https://gitlab.cta-observatory.org/cta-computing/suss/science-analysis-tools/science-analysis-tools/badges/main/pipeline.svg?key_text=docs&key_width=30)](http://cta-computing.gitlab-pages.cta-observatory.org/suss/science-analysis-tools/science-analysis-tools/)

`ctao-sat` is the official Science Analysis Tools (SAT) library for the Cherenkov Telescope Array Observatory (CTAO).
It transforms event lists and instrument response functions (IRFs) into high-level science products.

* [Documentation](http://cta-computing.gitlab-pages.cta-observatory.org/suss/science-analysis-tools/science-analysis-tools)
* [Code Repository](https://gitlab.cta-observatory.org/cta-computing/suss/science-analysis-tools/science-analysis-tools)
* [PyPI: ctao-sat](https://pypi.org/project/ctao-sat/)
